@@ -5,6 +5,7 @@ require_relative 'aws-partitions/partition'
 require_relative 'aws-partitions/partition_list'
 require_relative 'aws-partitions/region'
 require_relative 'aws-partitions/service'
+require_relative 'aws-partitions/metadata'
 
 require 'json'
 
@@ -195,7 +196,7 @@ module Aws
         end
       end
 
-      # @param [Hash] partition metadata
+      # @param [Hash] partition_metadata
       # @api private For Internal use only
       def merge_metadata(partition_metadata)
         default_partition_list.merge_metadata(partition_metadata)
@@ -247,9 +248,9 @@ module Aws
             'ACM' => 'acm',
             'ACMPCA' => 'acm-pca',
             'APIGateway' => 'apigateway',
+            'ARCZonalShift' => 'arc-zonal-shift',
             'AccessAnalyzer' => 'access-analyzer',
             'Account' => 'account',
-            'AlexaForBusiness' => 'a4b',
             'Amplify' => 'amplify',
             'AmplifyBackend' => 'amplifybackend',
             'AmplifyUIBuilder' => 'amplifyuibuilder',
@@ -257,43 +258,58 @@ module Aws
             'ApiGatewayV2' => 'apigateway',
             'AppConfig' => 'appconfig',
             'AppConfigData' => 'appconfigdata',
+            'AppFabric' => 'appfabric',
             'AppIntegrationsService' => 'app-integrations',
             'AppMesh' => 'appmesh',
             'AppRegistry' => 'servicecatalog-appregistry',
             'AppRunner' => 'apprunner',
             'AppStream' => 'appstream2',
             'AppSync' => 'appsync',
+            'AppTest' => 'apptest',
             'Appflow' => 'appflow',
             'ApplicationAutoScaling' => 'application-autoscaling',
             'ApplicationCostProfiler' => 'application-cost-profiler',
             'ApplicationDiscoveryService' => 'discovery',
             'ApplicationInsights' => 'applicationinsights',
+            'ApplicationSignals' => 'application-signals',
+            'Artifact' => 'artifact',
             'Athena' => 'athena',
             'AuditManager' => 'auditmanager',
             'AugmentedAIRuntime' => 'a2i-runtime.sagemaker',
             'AutoScaling' => 'autoscaling',
             'AutoScalingPlans' => 'autoscaling-plans',
+            'B2bi' => 'b2bi',
+            'BCMDataExports' => 'bcm-data-exports',
             'Backup' => 'backup',
             'BackupGateway' => 'backup-gateway',
-            'BackupStorage' => 'backupstorage',
             'Batch' => 'batch',
+            'Bedrock' => 'bedrock',
+            'BedrockAgent' => 'bedrock-agent',
+            'BedrockAgentRuntime' => 'bedrock-agent-runtime',
+            'BedrockRuntime' => 'bedrock-runtime',
             'BillingConductor' => 'billingconductor',
             'Braket' => 'braket',
             'Budgets' => 'budgets',
+            'Chatbot' => 'chatbot',
             'Chime' => 'chime',
             'ChimeSDKIdentity' => 'identity-chime',
             'ChimeSDKMediaPipelines' => 'media-pipelines-chime',
             'ChimeSDKMeetings' => 'meetings-chime',
             'ChimeSDKMessaging' => 'messaging-chime',
+            'ChimeSDKVoice' => 'voice-chime',
+            'CleanRooms' => 'cleanrooms',
+            'CleanRoomsML' => 'cleanrooms-ml',
             'Cloud9' => 'cloud9',
             'CloudControlApi' => 'cloudcontrolapi',
             'CloudDirectory' => 'clouddirectory',
             'CloudFormation' => 'cloudformation',
             'CloudFront' => 'cloudfront',
+            'CloudFrontKeyValueStore' => 'cloudfront-keyvaluestore',
             'CloudHSM' => 'cloudhsm',
             'CloudHSMV2' => 'cloudhsmv2',
             'CloudSearch' => 'cloudsearch',
             'CloudTrail' => 'cloudtrail',
+            'CloudTrailData' => 'cloudtrail-data',
             'CloudWatch' => 'monitoring',
             'CloudWatchEvents' => 'events',
             'CloudWatchEvidently' => 'evidently',
@@ -301,12 +317,14 @@ module Aws
             'CloudWatchRUM' => 'rum',
             'CodeArtifact' => 'codeartifact',
             'CodeBuild' => 'codebuild',
+            'CodeCatalyst' => 'codecatalyst',
             'CodeCommit' => 'codecommit',
+            'CodeConnections' => 'codeconnections',
             'CodeDeploy' => 'codedeploy',
             'CodeGuruProfiler' => 'codeguru-profiler',
             'CodeGuruReviewer' => 'codeguru-reviewer',
+            'CodeGuruSecurity' => 'codeguru-security',
             'CodePipeline' => 'codepipeline',
-            'CodeStar' => 'codestar',
             'CodeStarNotifications' => 'codestar-notifications',
             'CodeStarconnections' => 'codestar-connections',
             'CognitoIdentity' => 'cognito-identity',
@@ -322,8 +340,10 @@ module Aws
             'ConnectContactLens' => 'contact-lens',
             'ConnectParticipant' => 'participant.connect',
             'ConnectWisdomService' => 'wisdom',
+            'ControlCatalog' => 'controlcatalog',
             'ControlTower' => 'controltower',
             'CostExplorer' => 'ce',
+            'CostOptimizationHub' => 'cost-optimization-hub',
             'CostandUsageReportService' => 'cur',
             'CustomerProfiles' => 'profile',
             'DAX' => 'dax',
@@ -331,13 +351,17 @@ module Aws
             'DataExchange' => 'dataexchange',
             'DataPipeline' => 'datapipeline',
             'DataSync' => 'datasync',
+            'DataZone' => 'datazone',
             'DatabaseMigrationService' => 'dms',
+            'Deadline' => 'deadline',
             'Detective' => 'api.detective',
             'DevOpsGuru' => 'devops-guru',
             'DeviceFarm' => 'devicefarm',
             'DirectConnect' => 'directconnect',
             'DirectoryService' => 'ds',
+            'DirectoryServiceData' => 'ds-data',
             'DocDB' => 'rds',
+            'DocDBElastic' => 'docdb-elastic',
             'Drs' => 'drs',
             'DynamoDB' => 'dynamodb',
             'DynamoDBStreams' => 'streams.dynamodb',
@@ -349,6 +373,7 @@ module Aws
             'ECS' => 'ecs',
             'EFS' => 'elasticfilesystem',
             'EKS' => 'eks',
+            'EKSAuth' => 'eks-auth',
             'EMR' => 'elasticmapreduce',
             'EMRContainers' => 'emr-containers',
             'EMRServerless' => 'emr-serverless',
@@ -359,6 +384,7 @@ module Aws
             'ElasticLoadBalancingV2' => 'elasticloadbalancing',
             'ElasticTranscoder' => 'elastictranscoder',
             'ElasticsearchService' => 'es',
+            'EntityResolution' => 'entityresolution',
             'EventBridge' => 'events',
             'FIS' => 'fis',
             'FMS' => 'fms',
@@ -369,8 +395,11 @@ module Aws
             'ForecastQueryService' => 'forecastquery',
             'ForecastService' => 'forecast',
             'FraudDetector' => 'frauddetector',
+            'FreeTier' => 'freetier',
             'GameLift' => 'gamelift',
-            'GameSparks' => 'gamesparks',
+            'GeoMaps' => 'geo-maps',
+            'GeoPlaces' => 'geo-places',
+            'GeoRoutes' => 'geo-routes',
             'Glacier' => 'glacier',
             'GlobalAccelerator' => 'globalaccelerator',
             'Glue' => 'glue',
@@ -381,14 +410,16 @@ module Aws
             'GuardDuty' => 'guardduty',
             'Health' => 'health',
             'HealthLake' => 'healthlake',
-            'Honeycode' => 'honeycode',
             'IAM' => 'iam',
             'IVS' => 'ivs',
+            'IVSRealTime' => 'ivsrealtime',
             'IdentityStore' => 'identitystore',
             'Imagebuilder' => 'imagebuilder',
             'ImportExport' => 'importexport',
             'Inspector' => 'inspector',
             'Inspector2' => 'inspector2',
+            'InspectorScan' => 'inspector-scan',
+            'InternetMonitor' => 'internetmonitor',
             'IoT' => 'iot',
             'IoT1ClickDevicesService' => 'devices.iot1click',
             'IoT1ClickProjects' => 'projects.iot1click',
@@ -409,6 +440,7 @@ module Aws
             'Kafka' => 'kafka',
             'KafkaConnect' => 'kafkaconnect',
             'Kendra' => 'kendra',
+            'KendraRanking' => 'kendra-ranking',
             'Keyspaces' => 'cassandra',
             'Kinesis' => 'kinesis',
             'KinesisAnalytics' => 'kinesisanalytics',
@@ -417,14 +449,16 @@ module Aws
             'KinesisVideoArchivedMedia' => 'kinesisvideo',
             'KinesisVideoMedia' => 'kinesisvideo',
             'KinesisVideoSignalingChannels' => 'kinesisvideo',
+            'KinesisVideoWebRTCStorage' => 'kinesisvideo',
             'LakeFormation' => 'lakeformation',
             'Lambda' => 'lambda',
-            'LambdaPreview' => 'lambda',
+            'LaunchWizard' => 'launchwizard',
             'Lex' => 'runtime.lex',
             'LexModelBuildingService' => 'models.lex',
             'LexModelsV2' => 'models-v2-lex',
             'LexRuntimeV2' => 'runtime-v2-lex',
             'LicenseManager' => 'license-manager',
+            'LicenseManagerLinuxSubscriptions' => 'license-manager-linux-subscriptions',
             'LicenseManagerUserSubscriptions' => 'license-manager-user-subscriptions',
             'Lightsail' => 'lightsail',
             'LocationService' => 'geo',
@@ -435,23 +469,29 @@ module Aws
             'MTurk' => 'mturk-requester',
             'MWAA' => 'airflow',
             'MachineLearning' => 'machinelearning',
-            'Macie' => 'macie',
             'Macie2' => 'macie2',
+            'MailManager' => 'mail-manager',
             'MainframeModernization' => 'm2',
             'ManagedBlockchain' => 'managedblockchain',
+            'ManagedBlockchainQuery' => 'managedblockchain-query',
             'ManagedGrafana' => 'grafana',
+            'MarketplaceAgreement' => 'agreement-marketplace',
             'MarketplaceCatalog' => 'catalog.marketplace',
             'MarketplaceCommerceAnalytics' => 'marketplacecommerceanalytics',
+            'MarketplaceDeployment' => 'deployment-marketplace',
             'MarketplaceEntitlementService' => 'entitlement.marketplace',
             'MarketplaceMetering' => 'metering.marketplace',
+            'MarketplaceReporting' => 'reporting-marketplace',
             'MediaConnect' => 'mediaconnect',
             'MediaConvert' => 'mediaconvert',
             'MediaLive' => 'medialive',
             'MediaPackage' => 'mediapackage',
+            'MediaPackageV2' => 'mediapackagev2',
             'MediaPackageVod' => 'mediapackage-vod',
             'MediaStore' => 'mediastore',
             'MediaStoreData' => 'data.mediastore',
             'MediaTailor' => 'api.mediatailor',
+            'MedicalImaging' => 'medical-imaging',
             'MemoryDB' => 'memory-db',
             'Mgn' => 'mgn',
             'MigrationHub' => 'mgh',
@@ -459,18 +499,28 @@ module Aws
             'MigrationHubOrchestrator' => 'migrationhub-orchestrator',
             'MigrationHubRefactorSpaces' => 'refactor-spaces',
             'MigrationHubStrategyRecommendations' => 'migrationhub-strategy',
-            'Mobile' => 'mobile',
             'Neptune' => 'rds',
+            'NeptuneGraph' => 'neptune-graph',
+            'Neptunedata' => 'neptune-db',
             'NetworkFirewall' => 'network-firewall',
             'NetworkManager' => 'networkmanager',
-            'NimbleStudio' => 'nimble',
+            'NetworkMonitor' => 'networkmonitor',
+            'OAM' => 'oam',
+            'OSIS' => 'osis',
+            'Omics' => 'omics',
+            'OpenSearchServerless' => 'aoss',
             'OpenSearchService' => 'es',
             'OpsWorks' => 'opsworks',
             'OpsWorksCM' => 'opsworks-cm',
             'Organizations' => 'organizations',
             'Outposts' => 'outposts',
+            'PCS' => 'pcs',
             'PI' => 'pi',
             'Panorama' => 'panorama',
+            'PaymentCryptography' => 'controlplane.payment-cryptography',
+            'PaymentCryptographyData' => 'dataplane.payment-cryptography',
+            'PcaConnectorAd' => 'pca-connector-ad',
+            'PcaConnectorScep' => 'pca-connector-scep',
             'Personalize' => 'personalize',
             'PersonalizeEvents' => 'personalize-events',
             'PersonalizeRuntime' => 'personalize-runtime',
@@ -478,11 +528,15 @@ module Aws
             'PinpointEmail' => 'email',
             'PinpointSMSVoice' => 'sms-voice.pinpoint',
             'PinpointSMSVoiceV2' => 'sms-voice',
+            'Pipes' => 'pipes',
             'Polly' => 'polly',
             'Pricing' => 'api.pricing',
             'PrivateNetworks' => 'private-networks',
             'PrometheusService' => 'aps',
             'Proton' => 'proton',
+            'QApps' => 'data.qapps',
+            'QBusiness' => 'qbusiness',
+            'QConnect' => 'wisdom',
             'QLDB' => 'qldb',
             'QLDBSession' => 'session.qldb',
             'QuickSight' => 'quicksight',
@@ -494,13 +548,16 @@ module Aws
             'RedshiftDataAPIService' => 'redshift-data',
             'RedshiftServerless' => 'redshift-serverless',
             'Rekognition' => 'rekognition',
+            'Repostspace' => 'repostspace',
             'ResilienceHub' => 'resiliencehub',
+            'ResourceExplorer2' => 'resource-explorer-2',
             'ResourceGroups' => 'resource-groups',
             'ResourceGroupsTaggingAPI' => 'tagging',
             'RoboMaker' => 'robomaker',
             'RolesAnywhere' => 'rolesanywhere',
             'Route53' => 'route53',
             'Route53Domains' => 'route53domains',
+            'Route53Profiles' => 'route53profiles',
             'Route53RecoveryCluster' => 'route53-recovery-cluster',
             'Route53RecoveryControlConfig' => 'route53-recovery-control-config',
             'Route53RecoveryReadiness' => 'route53-recovery-readiness',
@@ -516,6 +573,7 @@ module Aws
             'SSM' => 'ssm',
             'SSMContacts' => 'ssm-contacts',
             'SSMIncidents' => 'ssm-incidents',
+            'SSMQuickSetup' => 'ssm-quicksetup',
             'SSO' => 'portal.sso',
             'SSOAdmin' => 'sso',
             'SSOOIDC' => 'oidc',
@@ -523,43 +581,57 @@ module Aws
             'SWF' => 'swf',
             'SageMaker' => 'api.sagemaker',
             'SageMakerFeatureStoreRuntime' => 'featurestore-runtime.sagemaker',
+            'SageMakerGeospatial' => 'sagemaker-geospatial',
+            'SageMakerMetrics' => 'metrics.sagemaker',
             'SageMakerRuntime' => 'runtime.sagemaker',
             'SagemakerEdgeManager' => 'edge.sagemaker',
             'SavingsPlans' => 'savingsplans',
+            'Scheduler' => 'scheduler',
             'Schemas' => 'schemas',
             'SecretsManager' => 'secretsmanager',
             'SecurityHub' => 'securityhub',
+            'SecurityLake' => 'securitylake',
             'ServerlessApplicationRepository' => 'serverlessrepo',
             'ServiceCatalog' => 'servicecatalog',
             'ServiceDiscovery' => 'servicediscovery',
             'ServiceQuotas' => 'servicequotas',
             'Shield' => 'shield',
             'Signer' => 'signer',
+            'SimSpaceWeaver' => 'simspaceweaver',
             'SimpleDB' => 'sdb',
             'SnowDeviceManagement' => 'snow-device-management',
             'Snowball' => 'snowball',
+            'SocialMessaging' => 'social-messaging',
+            'SsmSap' => 'ssm-sap',
             'States' => 'states',
             'StorageGateway' => 'storagegateway',
+            'SupplyChain' => 'scn',
             'Support' => 'support',
             'SupportApp' => 'supportapp',
             'Synthetics' => 'synthetics',
+            'TaxSettings' => 'tax',
             'Textract' => 'textract',
+            'TimestreamInfluxDB' => 'timestream-influxdb',
             'TimestreamQuery' => 'query.timestream',
             'TimestreamWrite' => 'ingest.timestream',
+            'Tnb' => 'tnb',
             'TranscribeService' => 'transcribe',
             'TranscribeStreamingService' => 'transcribestreaming',
             'Transfer' => 'transfer',
             'Translate' => 'translate',
+            'TrustedAdvisor' => 'trustedadvisor',
+            'VPCLattice' => 'vpc-lattice',
+            'VerifiedPermissions' => 'verifiedpermissions',
             'VoiceID' => 'voiceid',
             'WAF' => 'waf',
             'WAFRegional' => 'waf-regional',
             'WAFV2' => 'wafv2',
             'WellArchitected' => 'wellarchitected',
             'WorkDocs' => 'workdocs',
-            'WorkLink' => 'worklink',
             'WorkMail' => 'workmail',
             'WorkMailMessageFlow' => 'workmailmessageflow',
             'WorkSpaces' => 'workspaces',
+            'WorkSpacesThinClient' => 'thinclient',
             'WorkSpacesWeb' => 'workspaces-web',
             'XRay' => 'xray',
           }
